pitchtools.is_melodic_diatonic_interval_abbreviation
====================================================

.. autofunction:: abjad.tools.pitchtools.is_melodic_diatonic_interval_abbreviation.is_melodic_diatonic_interval_abbreviation
